# Contributing

- Create an issue or submit a pull request forked from the develop branch.
- For pull requests please refer to steps 1-6 at the top of [Contributing to Simple Icons](https://github.com/simple-icons/simple-icons/blob/develop/CONTRIBUTING.md)

Preconditions for pull request merge:
- For bug fixes a test that fails.
- Documentation and test updates for features.
